@@ -17,6 +17,14 @@ class CredentialType(Enum):
         return self.value
 
 
+class CountryCode(Enum):
+    INDIA = "IN"
+    THAILAND = "TH"
+
+    def __str__(self):
+        return self.value
+
+
 class Gender(Enum):
     MALE = "MALE"
     FEMALE = "FEMALE"
@@ -221,6 +229,7 @@ class UserRequest:
     identity: str
     requires_verification: bool = True
     password: str = None
+    region: str = CountryCode.INDIA
 
     def to_dict(self):
         request = {
