@@ -48,6 +48,7 @@ def test_user_profile_to_dict():
         "home_address",
         "work_address",
         "user_types",
+        "zone_id",
         "user_specific_features",
     ]:
         assert user_profile_dict[key] == user_profile_new_dict[key]
@@ -225,6 +226,7 @@ user_profile_dict = {
     },
     "id": "f77971a6-3a7f-4475-81b6-2fe9e085f0bc",
     "name": "sample_name",
+    "zone_id": "b402e055-2884-43a1-9e33-dbfe67e62971",
     "updated_at": "2018-10-18T13:04:55.643673",
     "work_address": {
         "location": {"lat": 27.88, "lng": 76.33},
